@@ -4,11 +4,10 @@
  *
  *  SPDX-License-Identifier: LGPL-2.1-or-later
  */
-#ifndef WAYLANDOUTPUTMANAGEMENT_H
-#define WAYLANDOUTPUTMANAGEMENT_H
+#pragma once
 
 #include "qwayland-kde-output-management-v2.h"
-#include "qwayland-kde-primary-output-v1.h"
+#include "qwayland-kde-output-order-v1.h"
 
 #include <QObject>
 #include <QSize>
@@ -42,19 +41,23 @@ public:
     WaylandOutputConfiguration *createConfiguration();
 };
 
-class WaylandPrimaryOutput : public QObject, public QtWayland::kde_primary_output_v1
+class WaylandOutputOrder : public QObject, public QtWayland::kde_output_order_v1
 {
     Q_OBJECT
 public:
-    WaylandPrimaryOutput(struct ::wl_registry *registry, int id, int version);
-    ~WaylandPrimaryOutput();
+    WaylandOutputOrder(struct ::wl_registry *registry, int id, int version);
+    ~WaylandOutputOrder();
+
+    QList<QString> order() const;
 
 Q_SIGNALS:
-    void primaryOutputChanged(const QString &outputName);
+    void outputOrderChanged(const QList<QString> &outputs);
 
-protected:
-    void kde_primary_output_v1_primary_output(const QString &outputName) override;
+private:
+    void kde_output_order_v1_output(const QString &output_name) override;
+    void kde_output_order_v1_done() override;
+
+    QList<QString> m_outputOrder;
+    QList<QString> m_pendingOutputOrder;
 };
 }
-
-#endif // WAYLANDOUTPUTMANAGEMENT_H
